// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KSYNTAXHIGHLIGHTING_VERSION_H
#define KSYNTAXHIGHLIGHTING_VERSION_H

#define KSYNTAXHIGHLIGHTING_VERSION_STRING "6.22.0"
#define KSYNTAXHIGHLIGHTING_VERSION_MAJOR 6
#define KSYNTAXHIGHLIGHTING_VERSION_MINOR 22
#define KSYNTAXHIGHLIGHTING_VERSION_PATCH 0
#define KSYNTAXHIGHLIGHTING_VERSION ((6<<16)|(22<<8)|(0))

#endif
